@@ -1426,7 +1426,7 @@ static int cue_open_audioxtr(char *path, struct burn_cue_file_cursor *crs,
 
 	ret= libdax_audioxtr_new(&xtr, path, 0);
 	if (ret <= 0)
-		return ret;
+		goto ex;
 	libdax_audioxtr_get_id(xtr, &fmt, &fmt_info, &num_channels,
 		 		&sample_rate, &bits_per_sample, &msb_first, 0);
 	if ((flag & 255) == 1) {
@@ -2146,6 +2146,12 @@ ex:
 		tracks = burn_session_get_tracks(session, &num_tracks);
 		for (i = 0; i < num_tracks; i++)
 			burn_track_free(tracks[i]);
+		if(text_packs != NULL) {
+			if(*text_packs != NULL)
+				free(*text_packs);
+			*text_packs = NULL;
+			*num_packs = 0;
+		}
 	} else {
 		if (fifo != NULL) {
 			*fifo = crs->fifo;
@@ -2155,6 +2161,8 @@ ex:
 	cue_crs_destroy(&crs, 0);
 	BURN_FREE_MEM(line);
 	BURN_FREE_MEM(msg);
+	if (fp != NULL)
+		fclose(fp);
 	return ret;
 }
 
