@@ -322,6 +322,9 @@ struct isoburn_read_opts {
     unsigned int nojoliet:1; /*< Do not read Joliet extensions */
     unsigned int noiso1999:1; /*< Do not read ISO 9660:1999 enhanced tree */
 
+    unsigned int do_ecma119_map:1; /* call iso_read_opts_set_ecma119_map() */
+    unsigned int map_mode:2;       /* argument for do_ecma119_map */
+
     /* ts A90121 */
     unsigned int noaaip:1;   /* Do not read AAIP for ACL and EA */
     unsigned int noacl:1;    /* Do not read ACL from external file objects */
@@ -351,11 +354,19 @@ struct isoburn_read_opts {
      * Enable or disable methods to automatically choose an input charset.
      * This eventually overrides input_charset.
      *
-     * bit0= allow to set the input character set automatically from
+     * bit0= set the input character set automatically from
      *       attribute "isofs.cs" of root directory
      */
     int auto_input_charset;
 
+    /**
+     * What to do in case of name longer than truncate_length:
+     *  0= throw FAILURE
+     *  1= truncate to truncate_length with MD5 of whole name at end
+     */
+    int truncate_mode;
+    int truncate_length;
+
     /* modified by the function isoburn_read_image */
     unsigned int hasRR:1; /*< It will be set to 1 if RR extensions are present,
                              to 0 if not. */
