@@ -365,6 +365,35 @@ void ecma119_node_free(Ecma119Node *node)
     free(node);
 }
 
+
+static
+int add_to_hidden_list(Ecma119Image *image, IsoFileSrc *src)
+{
+    int ret;
+    struct iso_filesrc_list_item *item;
+
+    LIBISO_ALLOC_MEM(item, struct iso_filesrc_list_item, 1);
+    item->src = src;
+    item->next = image->ecma119_hidden_list;
+    image->ecma119_hidden_list = item;
+    ret = ISO_SUCCESS;
+ex:
+    return ret;
+}
+
+
+int iso_filesrc_list_destroy(struct iso_filesrc_list_item **start_item)
+{
+    struct iso_filesrc_list_item *item, *next;
+
+    for (item = *start_item; item != NULL; item = next) {
+        next = item->next;
+        LIBISO_FREE_MEM(item);
+    }
+    return ISO_SUCCESS;
+}
+ 
+
 /**
  * @param flag
  *      bit0= iso is in a hidden directory. Thus hide it.
@@ -381,11 +410,12 @@ int create_tree(Ecma119Image *image, IsoNode *iso, Ecma119Node **tree,
     int max_path;
     char *iso_name= NULL, *ipath = NULL;
     IsoFileSrc *src = NULL;
-    IsoWriteOpts *opts = image->opts;
+    IsoWriteOpts *opts;
 
     if (image == NULL || iso == NULL || tree == NULL) {
         return ISO_NULL_POINTER;
     }
+    opts = image->opts;
     *tree = NULL;
 
     hidden = flag & 1;
@@ -430,6 +460,9 @@ int create_tree(Ecma119Image *image, IsoNode *iso, Ecma119Node **tree,
     case LIBISO_FILE:
         if (hidden) {
             ret = create_file_src(image, (IsoFile *) iso, &src);
+            if (ret <= 0)
+                goto ex;
+            ret = add_to_hidden_list(image, src); 
         } else {
             ret = create_file(image, (IsoFile*)iso, &node);
         }
@@ -470,6 +503,9 @@ int create_tree(Ecma119Image *image, IsoNode *iso, Ecma119Node **tree,
         if (image->eltorito) {
             if (hidden) {
                 ret = el_torito_catalog_file_src_create(image, &src);
+                if (ret <= 0)
+                    goto ex;
+                ret = add_to_hidden_list(image, src); 
             } else {
                 ret = create_boot_cat(image, (IsoBoot*)iso, &node);
             }
@@ -618,6 +654,7 @@ int mangle_single_dir(Ecma119Image *img, Ecma119Node *dir, int max_file_len,
     for (i = 0; i < nchildren; ++i) {
         char *name, *ext;
         char full_name[40];
+        const int full_max_len = 40 - 1;
         int max; /* computed max len for name, without extension */
         int j = i;
         int digits = 1; /* characters to change per name */
@@ -656,7 +693,8 @@ int mangle_single_dir(Ecma119Image *img, Ecma119Node *dir, int max_file_len,
             int change = 0; /* number to be written */
 
             /* copy name to buffer */
-            strcpy(full_name, children[i]->iso_name);
+            strncpy(full_name, children[i]->iso_name, full_max_len);
+            full_name[full_max_len] = 0;
 
             /* compute name and extension */
             dot = strrchr(full_name, '.');
