@@ -1,6 +1,6 @@
 /*
  * Copyright (c) 2007 Vreixo Formoso
- * Copyright (c) 2010 Thomas Schmitt
+ * Copyright (c) 2010 - 2014 Thomas Schmitt
  *
  * This file is part of the libisofs project; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License version 2 
@@ -58,6 +58,11 @@ struct el_torito_boot_image {
      * Whether the boot image seems to contain a boot_info_table
      */
     unsigned int seems_boot_info_table:1;
+    unsigned int seems_grub2_boot_info:1;
+    /**
+     * Whether the boot image seems to be capable of isohybrid
+     */
+    unsigned int seems_isohybrid_capable:1;
     /**
      * isolinux options
      * bit 0 -> whether to patch image
@@ -73,8 +78,8 @@ struct el_torito_boot_image {
     unsigned int isolinux_options;
     unsigned char type; /**< The type of image */
     unsigned char partition_type; /**< type of partition for HD-emul images */
-    short load_seg; /**< Load segment for the initial boot image. */
-    short load_size; /**< Number of sectors to load. */
+    uint16_t load_seg; /**< Load segment for the initial boot image. */
+    uint16_t load_size; /**< Number of sectors to load. */
 
     /* Byte 1 of Validation Entry or Section Header Entry:
        0= 80x86, 1= PowerPC, 2= Mac, 0xef= EFI */
@@ -155,4 +160,19 @@ int make_boot_info_table(uint8_t *buf, uint32_t pvd_lba,
 */
 int iso_patch_eltoritos(Ecma119Image *t);
 
+
+/* Parameters for patch_grub2_boot_image()
+   Might later become variables in struct el_torito_boot_image.
+*/
+#define Libisofs_grub2_elto_patch_poS    (512 * 5 - 12)
+#define Libisofs_grub2_elto_patch_offsT  5
+
+
+/* Maximum size of a boot image which is marked by
+   el_torito_set_isolinux_options() for patching (boot info table,
+   GRUB2 boot info, maybe others).
+*/
+#define Libisofs_elto_max_patchablE      (32 * 1024 * 1024)
+
+
 #endif /* LIBISO_ELTORITO_H */
