@@ -143,6 +143,7 @@ int Xorriso_new(struct XorrisO ** xorriso,char *progname, int flag)
  m->do_fat= 0;
  m->do_rockridge= 1;
  m->do_iso1999= 0;
+ m->ecma119_map= 1;
  m->do_aaip= 0;
  m->do_md5= 0;
  m->no_emul_toc= 0;
@@ -204,6 +205,7 @@ int Xorriso_new(struct XorrisO ** xorriso,char *progname, int flag)
  m->image_start_value[0]= 0;
  m->displacement= 0;
  m->displacement_sign= 0;
+ m->read_fs= 0;
  m->drives_exclusive= 1;
  m->early_stdio_test= 0;
  m->cache_num_tiles= 0;
@@ -242,6 +244,12 @@ int Xorriso_new(struct XorrisO ** xorriso,char *progname, int flag)
  m->alignment= 0;
  m->do_stream_recording= 0;
  m->dvd_obs= 0;
+ m->modesty_on_drive= 0;
+ m->min_buffer_usec= 5000;
+ m->max_buffer_usec= 25000;
+ m->buffer_timeout_sec= 120;
+ m->min_buffer_percent= 90;
+ m->max_buffer_percent= 95;
  m->stdio_sync= 0;
  m->stdio_sync_is_default= 1;
  m->keep_boot_image= 0;
@@ -314,6 +322,7 @@ int Xorriso_new(struct XorrisO ** xorriso,char *progname, int flag)
  m->do_disk_pattern= 2;
  m->temp_mem_limit= 16*1024*1024;
  m->file_size_limit= Xorriso_default_file_size_limiT;
+ m->file_name_limit= 255;
  m->disk_exclusions= NULL;
  m->iso_rr_hidings= NULL;
  m->joliet_hidings= NULL;
@@ -556,6 +565,8 @@ int Xorriso_destroy(struct XorrisO **xorriso, int flag)
    free(m->in_charset);
  if(m->out_charset!=NULL)
    free(m->out_charset);
+ Checkmediajob_destroy(&(m->check_media_default), 0);
+ Sectorbitmap_destroy(&(m->in_sector_map), 0);
  Xorriso_destroy_re(m,0);
  Exclusions_destroy(&(m->disk_exclusions), 0);
  Exclusions_destroy(&(m->iso_rr_hidings), 0);
