@@ -694,7 +694,7 @@ int Xorriso_expand_disk_pattern(struct XorrisO *xorriso,
    goto ex;
 
  count+= extra_filec;
- mem+= extra_filec*sizeof(char *);
+ (*mem)+= extra_filec * sizeof(char *);
 
  if(count<=0)
    {ret= 0; goto ex;}
