@@ -1,7 +1,7 @@
 
 /* xorriso - creates, loads, manipulates and burns ISO 9660 filesystem images.
 
-   Copyright 2007-2014 Thomas Schmitt, <scdbackup@gmx.net>
+   Copyright 2007-2015 Thomas Schmitt, <scdbackup@gmx.net>
 
    Provided under GPL version 2 or later.
 
@@ -439,6 +439,26 @@ int Xorriso_option_pwdx(struct XorrisO *xorriso, int flag)
 }
 
 
+/* Command -read_fs */
+int Xorriso_option_read_fs(struct XorrisO *xorriso, char *mode, int flag)
+{
+ if(strcmp(mode, "any") == 0) {
+   xorriso->read_fs= 0;
+ } else if(strcmp(mode, "norock") == 0) {
+   xorriso->read_fs= 1;
+ } else if(strcmp(mode, "nojoliet") == 0) {
+   xorriso->read_fs= 2;
+ } else if(strcmp(mode, "ecma119") == 0) {
+   xorriso->read_fs= 3;
+ } else {
+   sprintf(xorriso->info_text, "-read_fs: unknown mode '%s'", mode);
+   Xorriso_msgs_submit(xorriso, 0, xorriso->info_text, 0, "FAILURE", 0);
+   return(0);
+ }
+ return(1);
+}
+
+
 int Xorriso_option_read_mkisofsrc(struct XorrisO *xorriso, int flag)
 {
  int ret;
@@ -1608,21 +1628,22 @@ int Xorriso_option_toc_of(struct XorrisO *xorriso, char *which, int flag)
    toc_flag|= 1;
  if(strncmp(which, "in", 2) == 0) {
    if(xorriso->indev[0] == 0) {
-     Xorriso_msgs_submit(xorriso, 0, "-toc_of 'in' : No input drive aquired",
+     Xorriso_msgs_submit(xorriso, 0, "-toc_of 'in' : No input drive acquired",
                          0, "NOTE", 0);
      return(2);
    }
    ret= Xorriso_toc(xorriso, toc_flag | 0);
  } else if(strncmp(which, "out", 3) == 0) {
    if(xorriso->outdev[0] == 0) {
-     Xorriso_msgs_submit(xorriso, 0, "-toc_of 'out' : No output drive aquired",
+     Xorriso_msgs_submit(xorriso, 0,
+                         "-toc_of 'out' : No output drive acquired",
                          0, "NOTE", 0);
      return(2);
    }
    ret= Xorriso_toc(xorriso, toc_flag | 2);
  } else if(strncmp(which, "all", 3) == 0) {
    if(xorriso->indev[0] == 0 && xorriso->outdev[0] == 0) {
-     Xorriso_msgs_submit(xorriso, 0, "-toc_of 'all' : No drive aquired",
+     Xorriso_msgs_submit(xorriso, 0, "-toc_of 'all' : No drive acquired",
                          0, "NOTE", 0);
      return(2);
    }
@@ -1905,7 +1926,7 @@ int Xorriso_option_version(struct XorrisO *xorriso, int flag)
  sprintf(xorriso->result_line,
 "ISO 9660 Rock Ridge filesystem manipulator and CD/DVD/BD burn program\n");
  sprintf(xorriso->result_line+strlen(xorriso->result_line),
-"Copyright (C) 2014, Thomas Schmitt <scdbackup@gmx.net>, libburnia project.\n");
+"Copyright (C) 2015, Thomas Schmitt <scdbackup@gmx.net>, libburnia project.\n");
  Xorriso_result(xorriso, 0);
  sprintf(xorriso->result_line,
          "xorriso version   :  %d.%d.%d%s\n",
@@ -2036,7 +2057,7 @@ int Xorriso_option_volume_date(struct XorrisO *xorriso,
      ret= 1; goto ex;
    }
    ret= Decode_ecma119_format(&erg, timestring, 0);
-   if(ret <= 0) {
+   if(ret <= 0 || strlen(timestring) != 16) {
      sprintf(xorriso->info_text, "-volume_date uuid : Not an ECMA-119 time string. (16 decimal digits, range 1970... to 2999...)");
      Xorriso_msgs_submit(xorriso, 0, xorriso->info_text, 0, "FAILURE", 0);
      ret= 0; goto ex;
