@@ -1,7 +1,7 @@
 
 /* xorriso - creates, loads, manipulates and burns ISO 9660 filesystem images.
 
-   Copyright 2007-2013 Thomas Schmitt, <scdbackup@gmx.net>
+   Copyright 2007-2015 Thomas Schmitt, <scdbackup@gmx.net>
 
    Provided under GPL version 2 or later.
 
@@ -226,7 +226,7 @@ int Xorriso_set_problem_status(struct XorrisO *xorriso, char *severity,
  static int complaints= 0, complaint_limit= 5;
 #endif
 
- if(severity[0])
+ if(severity[0] && strlen(severity) < sizeof(xorriso->problem_status_text))
    sev_text= severity;
  ret= Xorriso__text_to_sev(sev_text, &sev, 0);
  if(ret<=0)
@@ -445,12 +445,12 @@ int Xorriso_decode_load_adr(struct XorrisO *xorriso, char *cmd,
 }
 
  
-int Xorriso_check_name_len(struct XorrisO *xorriso, char *name, int size,
-                           char *cmd, int flag)
+int Xorriso_check_thing_len(struct XorrisO *xorriso, char *name, int size,
+                            char *cmd, char *thing, int flag)
 {
  if((int) strlen(name) >= size) {
    sprintf(xorriso->info_text,
-           "Name too long with option %s (%d > %d)", cmd,
+           "%s too long with option %s (%d > %d)", thing, cmd,
            (int) strlen(name), size - 1);
    Xorriso_msgs_submit(xorriso, 0, xorriso->info_text, 0, "SORRY", 0);
    return(0);
@@ -459,6 +459,12 @@ int Xorriso_check_name_len(struct XorrisO *xorriso, char *name, int size,
 }
  
 
+int Xorriso_check_name_len(struct XorrisO *xorriso, char *name, int size,
+                           char *cmd, int flag)
+{
+ return Xorriso_check_thing_len(xorriso, name, size, cmd, "Name", flag);
+}
+
 
 /* @return <0 error , >=0 number of skipped dashes
 */
@@ -522,16 +528,18 @@ int Xorriso_count_args(struct XorrisO *xorriso, int argc, char **argv,
     "close","close_damaged",
     "commit_eject","compliance","copyright_file",
     "dev","dialog","disk_dev_ino","disk_pattern","displacement",
-    "dummy","dvd_obs","early_stdio_test", "eject",
-    "iso_rr_pattern","follow","format","fs","gid","grow_blindly","hardlinks",
+    "dummy","dvd_obs","early_stdio_test","ecma119_map","eject",
+    "iso_rr_pattern","file_name_limit","follow","format","fs",
+    "gid","grow_blindly","hardlinks",
     "hfsplus","history","indev","in_charset","joliet",
     "list_delimiter","list_extras","list_profiles","local_charset",
-    "mark","md5","mount_opts","not_leaf","not_list","not_mgt",
+    "mark","md5","mount_opts","modesty_on_drive",
+    "not_leaf","not_list","not_mgt",
     "options_from_file","osirrox","outdev","out_charset","overwrite",
     "pacifier","padding","path_list","pathspecs","pkt_output",
     "preparer_id","print","print_info","print_mark","prompt",
     "prog","prog_help","publisher","quoted_not_list","quoted_path_list",
-    "read_speed","reassure","report_about",
+    "read_fs","read_speed","reassure","report_about",
     "report_el_torito","report_system_area","rockridge",
     "rom_toc_scan","rr_reloc_dir","scsi_log",
     "session_log","sh_style_result","signal_handling","sleep",
@@ -666,9 +674,10 @@ int Xorriso_cmd_sorting_rank(struct XorrisO *xorriso,
    "mount_opts", "mount_cmd", "session_string",
 
    "* Influencing the behavior of image loading:",
-   "read_speed", "load", "displacement",
+   "read_speed", "load", "displacement", "read_fs",
    "drive_class", "assert_volid", "in_charset",
    "auto_charset", "hardlinks", "acl", "xattr", "md5", "for_backup",
+   "ecma119_map",
    "disk_dev_ino", "rom_toc_scan", "calm_drive", "ban_stdio_write",
    "early_stdio_test", "data_cache_size",
 
@@ -683,7 +692,8 @@ int Xorriso_cmd_sorting_rank(struct XorrisO *xorriso,
    "toc", "toc_of", "pvd_info", "report_system_area", "report_el_torito",
 
    "* Settings for file insertion:",
-   "file_size_limit", "not_mgt", "not_paths", "not_leaf", "not_list",
+   "file_name_limit", "file_size_limit",
+   "not_mgt", "not_paths", "not_leaf", "not_list",
    "quoted_not_list", "follow", "pathspecs", "overwrite", "split_size",
 
    "* Navigation in ISO image and disk filesystem (1):",
@@ -728,6 +738,7 @@ int Xorriso_cmd_sorting_rank(struct XorrisO *xorriso,
    "abstract_file", "biblio_file", "preparer_id", "application_use",
    "out_charset", "read_mkisofsrc",
    "uid", "gid", "zisofs", "speed", "stream_recording", "dvd_obs",
+   "modesty_on_drive",
    "stdio_sync", "dummy", "fs", "close", "padding", "write_type",
    "grow_blindly", "pacifier", "scdbackup_tag",
 
@@ -1250,6 +1261,10 @@ next_command:;
    (*idx)++;
    ret= Xorriso_option_early_stdio_test(xorriso, arg1, 0);
 
+ } else if(strcmp(cmd,"ecma119_map")==0) {
+   (*idx)++;
+   ret= Xorriso_option_ecma119_map(xorriso, arg1, 0);
+
  } else if(strcmp(cmd,"eject")==0) {
    (*idx)++;
    ret= Xorriso_option_eject(xorriso, arg1, 0);
@@ -1295,6 +1310,10 @@ next_command:;
    (*idx)+= 2;
    ret= Xorriso_option_extract(xorriso, arg1, arg2, 32);
 
+ } else if(strcmp(cmd,"file_name_limit")==0) {
+   (*idx)++;
+   ret= Xorriso_option_file_name_limit(xorriso, arg1, 0);
+
  } else if(strcmp(cmd,"file_size_limit")==0) {
    ret= Xorriso_option_file_size_limit(xorriso, argc, argv, idx, 0);
 
@@ -1456,6 +1475,13 @@ next_command:;
    (*idx)++;
    ret= Xorriso_option_md5(xorriso, arg1, 0);
 
+ } else if(strcmp(cmd,"mkdir")==0 || strcmp(cmd,"mkdiri")==0) {
+   ret= Xorriso_option_mkdiri(xorriso, argc, argv, idx, 0);
+
+ } else if(strcmp(cmd, "modesty_on_drive")==0) {
+   (*idx)++;
+   ret= Xorriso_option_modesty_on_drive(xorriso, arg1, 0);
+
  } else if(strcmp(cmd, "mount") == 0 || strcmp(cmd, "mount_cmd") == 0) {
    (*idx)+= 4;
    if((*idx)>argc) {
@@ -1484,9 +1510,6 @@ next_command:;
  } else if(strcmp(cmd,"mv")==0 || strcmp(cmd,"mvi")==0) {
    ret= Xorriso_option_mvi(xorriso, argc, argv, idx, 0);
 
- } else if(strcmp(cmd,"mkdir")==0 || strcmp(cmd,"mkdiri")==0) {
-   ret= Xorriso_option_mkdiri(xorriso, argc, argv, idx, 0);
-
  } else if(strcmp(cmd,"named_pipe_loop")==0) {
    if((*idx) + 3 < argc)
      arg4= argv[(*idx) + 3];
@@ -1629,6 +1652,10 @@ next_command:;
    (*idx)++;
    ret= Xorriso_option_path_list(xorriso, arg1, 1);
 
+ } else if(strcmp(cmd,"read_fs")==0) {
+   (*idx)++;
+   ret= Xorriso_option_read_fs(xorriso, arg1, 0);
+
  } else if(strcmp(cmd,"read_mkisofsrc")==0) {
    ret= Xorriso_option_read_mkisofsrc(xorriso, 0);
 
@@ -2454,6 +2481,8 @@ int Xorriso_read_as_mkisofsrc(struct XorrisO *xorriso, char *path, int flag)
      /* >>> ??? complain ? abort reading ? */;
 
    }
+   if(ret <= 0)
+     goto ex;
  }
  xorriso->mkisofsrc_done= 1;
  ret= 1;
@@ -2576,7 +2605,7 @@ int Xorriso_program_arg_bsl(struct XorrisO *xorriso, int argc, char ***argv,
  Xorriso_alloc_meM(cmd_data, char, cmd_data_size);
  new_argv= (char **) Smem_malloC(argc * sizeof(char *));
  if(new_argv == NULL)
-   return(-1); 
+   {ret= -1; goto ex;}
  for(i= 0; i < argc; i++) {
    new_argv[i]= strdup((*argv)[i]);
    if(new_argv[i] == NULL)
@@ -2864,7 +2893,7 @@ int Xorriso_execv(struct XorrisO *xorriso, char *cmd,
 
  child_pid= fork();
  if(child_pid==-1) 
-   return(-1);
+   {ret= -1; goto ex;}
 
  if(child_pid==0) {
                      /* this is the child process */
