@@ -25,7 +25,8 @@
    This architecture is fully public since version 0.5.8. From then on, new
    features get marked by
      @since major.minor.micro
-   If this mark is missing, then the feature was present before release 0.5.8.
+   The option calls may have older "since" marks which then tell when the
+   corresponding command was introduced in the command interpreter.
 
    Please note that struct XorrisO and its API calls are _not_ thread-safe in
    general. It is not permissible to run two API calls on the same
@@ -68,7 +69,7 @@ struct XorrisO;
 */
 #define Xorriso_header_version_majoR  1
 #define Xorriso_header_version_minoR  4
-#define Xorriso_header_version_micrO  0
+#define Xorriso_header_version_micrO  2
 
 
 /** If needed: Something like ".pl01" to indicate a bug fix. Normally empty.
@@ -418,7 +419,7 @@ int Xorriso_execute_option(struct XorrisO *xorriso, char *line, int flag);
                               0= off
                               1= in_double_quotes
                               2= in_quotes
-                              3= with_quoted_input resp. on
+                              3= with_quoted_input
                       bit5=   Prepend the program name as (*argv)[0], so that
                               *argv is suitable for Xorriso_interpreter()
                               and other calls which expect this.
@@ -460,6 +461,7 @@ void Xorriso__dispose_words(int *argc, char ***argv);
    @return        <=0 error, 1= dialog mode ended normally ,
                   3= dialog mode ended normally,interpreter asks to end program
 */
+/* @since 0.1.0 */
 int Xorriso_dialog(struct XorrisO *xorriso, int flag);
 
 
@@ -992,7 +994,7 @@ struct Xorriso_lsT;
     the redirection is ended by a call to Xorriso_pull_outlists() with the
     stack_handle value returned by this call.
     If Xorriso_option_pkt_output() is set to "on", then it will consolidate
-    output in the result_list of Xorriso_fetch_outlists() resp.
+    output in the result_list of Xorriso_fetch_outlists() and
     Xorriso_pull_outlists().
     @param xorriso      The environment handle
     @param stack_handle returns an id number which is unique as long as
@@ -1068,8 +1070,8 @@ int Xorriso_peek_outlists(struct XorrisO *xorriso, int stack_handle,
 
 
 /** Disable the redirection given by stack_handle. If it was the current
-    receiver of messages then switch output to the next older redirection
-    resp. to the normal channels if no redirections are stacked any more.
+    receiver of messages then switch output to the next older redirection,
+    or to the normal channels if no redirections are stacked any more.
     The messages collected by the disabled redirection are handed out as
     two lists. Both lists have to be disposed via Xorriso_lst_destroy_all() 
     when they are no longer needed.
@@ -1097,7 +1099,7 @@ int Xorriso_pull_outlists(struct XorrisO *xorriso, int stack_handle,
     @param xorriso        The environment handle
     @param result_handler Pointer to the function which shall be called with
                           each result message. A NULL pointer causes output
-                          to be directed to stdout resp. to be interpreted
+                          to be directed to stdout or to be interpreted
                           as -pkt_output format if this is enabled by
                           Xorriso_option_pkt_output().
                           The function should return 1. A return value of -1
@@ -1108,7 +1110,7 @@ int Xorriso_pull_outlists(struct XorrisO *xorriso, int stack_handle,
                           Submit NULL if result_handler is NULL.
     @param info_handler   Pointer to the function which shall be called with
                           each info message. A NULL pointer causes output to
-                          be directed to stderr resp. to -as mkisofs -log-file.
+                          be directed to stderr or to -as mkisofs -log-file.
                           The function should return 1. A return value of -1
                           urges not to call again with further lines.
     @param info_handle    The first argument of (*info_handler)(). It shall
@@ -1151,7 +1153,7 @@ char *Xorriso_lst_get_text(struct Xorriso_lsT *entry, int flag);
 
 /** Obtain the address of the next item in the chain of messages.
     An iteration over the output of Xorriso_pull_outlists() starts at the
-    returned result_list resp. info_list and ends when this function returns
+    returned result_list or info_list and ends when this function returns
     NULL.
     @param entry    The current list item
     @param flag     unused yet, submit 0
@@ -1211,10 +1213,15 @@ int Xorriso_lst_destroy_all(struct Xorriso_lsT **lstring, int flag);
    Yet undefined flag bits might get a meaning in future. Unset bits will
    then produce the traditional behavior, whereas set bits might bring
    surprises to inadverted callers.
+
+   The API is available
+     @since 0.5.8
+   Earlier "since" marks refer to availability in the command interpreter.
 */
 
 
 /* Command -abort_on */
+/* @since 0.1.0 */
 int Xorriso_option_abort_on(struct XorrisO *xorriso, char *severity, int flag);
 
 /* Command -abstract_file */
@@ -1223,23 +1230,26 @@ int Xorriso_option_abstract_file(struct XorrisO *xorriso, char *name,
                                  int flag);
 
 /* Command -acl "on"|"off" */
+/* @since 0.3.4 */
 int Xorriso_option_acl(struct XorrisO *xorriso, char *mode, int flag);
 
 /* Command -add */
 /* @param flag bit0=do not report the added item
                bit1=do not reset pacifier, no final pacifier message
 */
+/* @since 0.1.0 */
 int Xorriso_option_add(struct XorrisO *xorriso, int argc, char **argv,
                        int *idx, int flag);
 
 /* Command -add_plainly "on"|"off" */
+/* @since 0.1.0 */
 int Xorriso_option_add_plainly(struct XorrisO *xorriso, char *mode,
                                    int flag);
 
-
 /* Command -alter_date, -alter_date_r */
 /* @param flag bit0=recursive (-alter_date_r)
 */
+/* @since 0.1.0 */
 int Xorriso_option_alter_date(struct XorrisO *xorriso, 
                               char *time_type, char *timestring,
                               int argc, char **argv, int *idx, int flag);
@@ -1250,6 +1260,7 @@ int Xorriso_option_append_partition(struct XorrisO *xorriso, char *partno_text,
                                   char *type_text, char *image_path, int flag);
 
 /* Command -application_id */
+/* @since 0.3.0 */
 int Xorriso_option_application_id(struct XorrisO *xorriso, char *name, 
                                   int flag);
 
@@ -1262,21 +1273,26 @@ int Xorriso_option_application_use(struct XorrisO *xorriso, char *path,
 /* @param flag bit0=do not report the added item
                bit1=do not reset pacifier, no final pacifier message
 */  
+/* @since 0.1.2 */
 int Xorriso_option_as(struct XorrisO *xorriso, int argc, char **argv,
                       int *idx, int flag);
 
 /* Command -assert_volid */
+/* @since 0.3.2 */
 int Xorriso_option_assert_volid(struct XorrisO *xorriso, char *pattern,
                                 char *severity, int flag);
 
 /* Command -auto_charset "on"|"off" */
+/* @since 0.3.8 */
 int Xorriso_option_auto_charset(struct XorrisO *xorriso, char *mode, int flag);
 
 /* Command -backslash_codes */
+/* @since 0.3.0 */
 int Xorriso_option_backslash_codes(struct XorrisO *xorriso, char *mode,
                                    int flag);
 
 /* Command -ban_stdio_write */
+/* @since 0.1.0 */
 int Xorriso_option_ban_stdio_write(struct XorrisO *xorriso, int flag);
 
 /* Command -biblio_file */
@@ -1287,19 +1303,24 @@ int Xorriso_option_biblio_file(struct XorrisO *xorriso, char *name, int flag);
 /* @param flag bit0= format rather than blank
    @return <=0 error , 1 success, 2 revoked by -reassure
 */
+/* @since 0.1.0 */
 int Xorriso_option_blank(struct XorrisO *xorriso, char *mode, int flag);
 
 /* Command -boot_image */
+/* @since 0.1.0 */
 int Xorriso_option_boot_image(struct XorrisO *xorriso, char *form,
                               char *treatment, int flag);
 
 /* Command -calm_drive */
+/* @since 0.4.2 */
 int Xorriso_option_calm_drive(struct XorrisO *xorriso, char *which, int flag);
 
 /* Command -cd alias -cdi */
+/* @since 0.1.0 */
 int Xorriso_option_cdi(struct XorrisO *xorriso, char *iso_rr_path, int flag);
 
 /* Command -cdx */
+/* @since 0.1.0 */
 int Xorriso_option_cdx(struct XorrisO *xorriso, char *disk_path, int flag);
 
 /* Command -changes_pending */
@@ -1307,10 +1328,12 @@ int Xorriso_option_cdx(struct XorrisO *xorriso, char *disk_path, int flag);
 int Xorriso_option_changes_pending(struct XorrisO *xorriso, char *state,
                                    int flag);
 
-/* Command -charset */
+/* Commands -charset, -in_charset, -out_charset, -local_charset */
 /* @param flag bit0= set in_charset
                bit1= set out_charset
+               bit2= set local_charset
 */
+/* @since 0.3.0 */
 int Xorriso_option_charset(struct XorrisO *xorriso, char *name, int flag);
 
 /* Command -check_md5 and -check_md5_r
@@ -1319,32 +1342,38 @@ int Xorriso_option_charset(struct XorrisO *xorriso, char *name, int flag);
                bit2= do not issue pacifier messages at all
                bit3= recursive: -check_md5_r
 */
+/* @since 0.4.2 */
 int Xorriso_option_check_md5(struct XorrisO *xorriso,
                              int argc, char **argv, int *idx, int flag);
 
 /* Command -check_media */
+/* @since 0.2.4 */
 int Xorriso_option_check_media(struct XorrisO *xorriso,
                                int argc, char **argv, int *idx, int flag);
 
 /* Command -check_media_defaults */
+/* @since 0.2.6 */
 int Xorriso_option_check_media_defaults(struct XorrisO *xorriso,
                                     int argc, char **argv, int *idx, int flag);
 
-/* Command -chgrp alias -chgrpi , chgrp_r alias chgrpi */
+/* Command -chgrp alias -chgrpi , chgrp_r alias chgrp_ri */
 /* @param flag bit0=recursive (-chgrp_r)
 */
+/* @since 0.1.0 */
 int Xorriso_option_chgrpi(struct XorrisO *xorriso, char *gid,
                           int argc, char **argv, int *idx, int flag);
 
 /* Command -chmod alias -chmodi , -chmod_r alias chmod_ri */
 /* @param flag bit0=recursive (-chmod_r)
 */
+/* @since 0.1.0 */
 int Xorriso_option_chmodi(struct XorrisO *xorriso, char *mode,
                           int argc, char **argv, int *idx, int flag);
 
 /* Command -chown alias -chowni , chown_r alias chown_ri */
 /* @param flag bit0=recursive (-chown_r)
 */
+/* @since 0.1.0 */
 int Xorriso_option_chowni(struct XorrisO *xorriso, char *uid,
                           int argc, char **argv, int *idx, int flag);
 
@@ -1354,6 +1383,7 @@ int Xorriso_option_clone(struct XorrisO *xorriso, char *origin, char *dest,
                          int flag);
 
 /* Command -close "on"|"off"| @since 1.3.4 "as_needed" */
+/* @since 0.1.0 */
 int Xorriso_option_close(struct XorrisO *xorriso, char *mode, int flag);
 
 /* Command -close_damaged */
@@ -1362,6 +1392,7 @@ int Xorriso_option_close_damaged(struct XorrisO *xorriso, char *mode,
                                  int flag);
 
 /* Command -close_filter_list */
+/* @since 0.3.8 */
 int Xorriso_option_close_filter_list(struct XorrisO *xorriso, int flag);
 
 /* Command -commit */
@@ -1370,11 +1401,13 @@ int Xorriso_option_close_filter_list(struct XorrisO *xorriso, int flag);
                bit1= do not perform eventual -reassure
    @return <=0 error , 1 success, 2 revoked by -reassure
 */
+/* @since 0.1.0 */
 int Xorriso_option_commit(struct XorrisO *xorriso, int flag);
 
 /* Command -commit_eject  */
 /* @return <=0 error , 1 success, 2 revoked by -reassure
 */
+/* @since 0.1.0 */
 int Xorriso_option_commit_eject(struct XorrisO *xorriso, char *which, int flag);
 
 /* Command -compare and -compare_r
@@ -1383,10 +1416,12 @@ int Xorriso_option_commit_eject(struct XorrisO *xorriso, char *which, int flag);
                bit2= do not issue pacifier messages at all
                bit3= recursive: -compare_r
 */
+/* @since 0.1.2 */
 int Xorriso_option_compare(struct XorrisO *xorriso, char *disk_path,
                            char *iso_path, int flag);
 
 /* Command -compliance */
+/* @since 0.3.0 */
 int Xorriso_option_compliance(struct XorrisO *xorriso, char *mode, int flag);
 
 /* Command -concat */
@@ -1405,17 +1440,22 @@ int Xorriso_option_cp_clone(struct XorrisO *xorriso, int argc, char **argv,
                             int *idx, int flag);
 
 /* Command -cpr alias -cpri */
+/* @since 0.1.0 */
 int Xorriso_option_cpri( struct XorrisO *xorriso, int argc, char **argv,
                          int *idx, int flag);
 
 /* Command -cpx , -cpax, -cp_rx , -cp_rax */
 /* @param flag bit0= recursive (-cp_rx, -cp_rax)
+                     @since 0.2.0
                bit1= full property restore (-cpax, -cp_rax)
+                     @since 0.2.0
 */
+/* @since 0.1.8 */
 int Xorriso_option_cpx(struct XorrisO *xorriso, int argc, char **argv,
                          int *idx, int flag);
 
 /* Command -cut_out */
+/* @since 0.1.2 */
 int Xorriso_option_cut_out(struct XorrisO *xorriso, char *disk_path,
                 char *start, char *count, char *iso_rr_path, int flag);
 
@@ -1423,6 +1463,7 @@ int Xorriso_option_cut_out(struct XorrisO *xorriso, char *disk_path,
 /* @param flag bit0=use as indev , bit1= use as outdev
    @return <=0 error , 1 success, 2 revoked by -reassure
 */
+/* @since 0.1.0 */
 int Xorriso_option_dev(struct XorrisO *xorriso, char *adr, int flag);
 
 /* Command -data_cache_size */
@@ -1432,17 +1473,23 @@ int Xorriso_option_data_cache_size(struct XorrisO *xorriso, char *num_tiles,
 
 /* Command -devices */
 /* @param flag bit0= perform -device_links rather than -devices
+                     @since 1.1.4
    @return <=0 error , 1 success, 2 revoked by -reassure
 */
+/* @since 0.1.0 */
 int Xorriso_option_devices(struct XorrisO *xorriso, int flag);
 
 /* Command -dialog "on"|"off" */
+/* @since 0.2.8 */
+/* (since 0.1.0 there was -dialog and -dialog_reset without arg) */
 int Xorriso_option_dialog(struct XorrisO *xorriso, char *mode, int flag);
 
 /* Command -disk_dev_ino "on"|"off" */
+/* @since 0.3.4 */
 int Xorriso_option_disk_dev_ino(struct XorrisO *xorriso, char *mode, int flag);
 
 /* Command -disk_pattern "on"|"ls"|"off" */
+/* @since 0.1.0 */
 int Xorriso_option_disk_pattern(struct XorrisO *xorriso, char *mode, int flag);
 
 /* Command -displacement [-]offset */
@@ -1451,13 +1498,16 @@ int Xorriso_option_displacement(struct XorrisO *xorriso, char *value,
                                 int flag);
 
 /* Command -drive_class */
+/* @since 0.3.2 */
 int Xorriso_option_drive_class(struct XorrisO *xorriso,
                                char *d_class, char *pattern, int flag);
 
 /* Command -dummy "on"|"off" */
+/* @since 0.1.0 */
 int Xorriso_option_dummy(struct XorrisO *xorriso, char *mode, int flag);
 
 /* Command -dvd_obs "default"|"32k"|"64k" */
+/* @since 0.4.8 */
 int Xorriso_option_dvd_obs(struct XorrisO *xorriso, char *obs, int flag);
 
 /* Command -early_stdio_test */
@@ -1465,26 +1515,35 @@ int Xorriso_option_dvd_obs(struct XorrisO *xorriso, char *obs, int flag);
 int Xorriso_option_early_stdio_test(struct XorrisO *xorriso, char *mode,
                                     int flag);
 
+/* Command -ecma119_map */
+/* @since 1.4.2 */
+int Xorriso_option_ecma119_map(struct XorrisO *xorriso, char *mode, int flag);
+
 /* Command -eject */
 /* @param flag bit0=do not report toc of eventually remaining drives
 */
+/* @since 0.1.0 */
 int Xorriso_option_eject(struct XorrisO *xorriso, char *which, int flag);
 
 /* Command -end , and -rollback_end */
 /* @param flag bit0= discard pending changes 
    @return <=0 error , 1 success, 2 revoked by -reassure
 */
+/* @since 0.1.0 */
 int Xorriso_option_end(struct XorrisO *xorriso, int flag);
 
 /* Command -errfile_log marked|plain  path|-|"" */
+/* @since 0.1.2 */
 int Xorriso_option_errfile_log(struct XorrisO *xorriso,
                                char *mode, char *path, int flag);
 
 /* Command -error_behavior */
+/* @since 0.1.6 */
 int Xorriso_option_error_behavior(struct XorrisO *xorriso, 
                                   char *occasion, char *behavior, int flag);
 
 /* Command -external_filter */
+/* @since 0.3.8 */
 int Xorriso_option_external_filter(struct XorrisO *xorriso,
                                    int argc, char **argv, int *idx, int flag);
 
@@ -1493,14 +1552,22 @@ int Xorriso_option_external_filter(struct XorrisO *xorriso,
                bit1=do not reset pacifier, no final pacifier message
                bit5= -extract_single: do not insert directory tree
 */
+/* @since 0.2.0 */
 int Xorriso_option_extract(struct XorrisO *xorriso, char *disk_path,
                        char *iso_path, int flag);
 
 /* Command -extract_cut */
+/* @since 0.2.6 */
 int Xorriso_option_extract_cut(struct XorrisO *xorriso, char *iso_rr_path,
                           char *start, char *count, char *disk_path, int flag);
 
+/* Command -file_name_limit */
+/* @since 1.4.2 */
+int Xorriso_option_file_name_limit(struct XorrisO *xorriso, char *value,
+                                   int flag);
+
 /* Command -file_size_limit */
+/* @since 0.2.6 */
 int Xorriso_option_file_size_limit(struct XorrisO *xorriso,
                                    int argc, char **argv, int *idx, int flag);
 
@@ -1510,34 +1577,55 @@ int Xorriso_option_file_size_limit(struct XorrisO *xorriso,
                bit1= do not reset pacifier, no final pacifier message
                      do not reset find_compare_result
 */ 
+/* @since 0.1.0 */
 int Xorriso_option_find(struct XorrisO *xorriso, int argc, char **argv,
                        int *idx, int flag);
 
 /* Command -follow */
+/* @since 0.1.0 */
 int Xorriso_option_follow(struct XorrisO *xorriso, char *mode, int flag);
 
+/* Command -for_backup is a shortcut for
+     Xorriso_option_hardlinks(xorriso, "on", 0);
+     Xorriso_option_acl(xorriso, "on", 0);
+     Xorriso_option_xattr(xorriso, "on", 0);
+     Xorriso_option_md5(xorriso, "on", 0);
+*/
+/* @since 0.4.0 */
+
 /* Command -fs */
+/* @since 0.1.0 */
 int Xorriso_option_fs(struct XorrisO *xorriso, char *size, int flag);
 
-/* Command -getfacl alias -getfacli, -getfacl_r alias -getfacl_ri */
+/* Commands -getfacl alias -getfacli, -getfacl_r alias -getfacl_ri
+            -getfattr alias getfattri
+ */
 /* @param flag bit0=recursive -getfacl_r
+               bit1= getfattr rather than getfacl
+               bit3= with bit1: do not ignore eventual non-user attributes
 */
+/* @since 0.3.4 */
 int Xorriso_option_getfacli(struct XorrisO *xorriso,
                             int argc, char **argv, int *idx, int flag);
 
 /* Command -gid */
+/* @since 0.1.0 */
 int Xorriso_option_gid(struct XorrisO *xorriso, char *gid, int flag);
 
 /* Command -grow_blindly */
+/* @since 0.2.2 */
 int Xorriso_option_grow_blindly(struct XorrisO *xorriso, char *msc2, int flag);
 
 /* Command -hardlinks "on"|"off" */
+/* @since 0.4.0 */
 int Xorriso_option_hardlinks(struct XorrisO *xorriso, char *mode, int flag);
 
 /* Command -help and part of -prog_help */
+/* @since 0.1.0 */
 int Xorriso_option_help(struct XorrisO *xorriso, int flag);
 
 /* Option -hfsplus "on"|"off" */
+/* @since 1.2.4 */
 int Xorriso_option_hfsplus(struct XorrisO *xorriso, char *mode, int flag);
 
 /* Command -hide */
@@ -1546,9 +1634,11 @@ int Xorriso_option_hide(struct XorrisO *xorriso, char *hide_state,
                         int argc, char **argv, int *idx, int flag);
 
 /* Command -history */
+/* @since 0.1.0 */
 int Xorriso_option_history(struct XorrisO *xorriso, char *line, int flag);
 
 /* Command -iso_rr_pattern "on"|"ls"|"off" */
+/* @since 0.1.0 */
 int Xorriso_option_iso_rr_pattern(struct XorrisO *xorriso, char *mode,
                                   int flag);
 
@@ -1558,6 +1648,7 @@ int Xorriso_option_jigdo(struct XorrisO *xorriso, char *aspect, char *arg,
                          int flag);
 
 /* Command -joliet "on"|"off" */
+/* @since 0.1.0 */
 int Xorriso_option_joliet(struct XorrisO *xorriso, char *mode, int flag);
 
 /* Command -launch_frontend */
@@ -1570,6 +1661,7 @@ int Xorriso_option_launch_frontend(struct XorrisO *xorriso,
 int Xorriso_option_list_arg_sorting(struct XorrisO *xorriso, int flag);
 
 /* Command -list_delimiter */
+/* @since 0.2.6 */
 int Xorriso_option_list_delimiter(struct XorrisO *xorriso, char *text,
                                   int flag);
 
@@ -1578,9 +1670,11 @@ int Xorriso_option_list_delimiter(struct XorrisO *xorriso, char *text,
 int Xorriso_option_list_extras(struct XorrisO *xorriso, char *mode, int flag);
 
 /* Command -list_formats */
+/* @since 0.1.6 */
 int Xorriso_option_list_formats(struct XorrisO *xorriso, int flag);
 
 /* Command -list_profiles */
+/* @since 0.4.2 */
 int Xorriso_option_list_profiles(struct XorrisO *xorriso, char *which,
                                  int flag);
 
@@ -1597,10 +1691,12 @@ int Xorriso_option_lnsi(struct XorrisO *xorriso, char *target, char *path,
 /* @param flag bit0= with adr_mode sbsector: adr_value is possibly 16 too high
    @return <=0 error , 1 success, 2 revoked by -reassure
 */
+/* @since 0.1.6 */
 int Xorriso_option_load(struct XorrisO *xorriso, char *adr_mode,
                           char *adr_value, int flag);
 
 /* Command -logfile */
+/* @since 0.1.0 */
 int Xorriso_option_logfile(struct XorrisO *xorriso, char *channel, 
                                                       char *fileadr, int flag);
 
@@ -1612,6 +1708,7 @@ int Xorriso_option_logfile(struct XorrisO *xorriso, char *channel,
                bit2= -du rather than -ls
                bit3= list directories as themselves (-lsd)  
 */
+/* @since 0.1.0 */
 int Xorriso_option_lsi(struct XorrisO *xorriso, int argc, char **argv,
                       int *idx, int flag);
 
@@ -1621,13 +1718,16 @@ int Xorriso_option_lsi(struct XorrisO *xorriso, int argc, char **argv,
                bit2= du rather than ls
                bit3= list directories as themselves (ls -d)
 */
+/* @since 0.1.0 */
 int Xorriso_option_lsx(struct XorrisO *xorriso, int argc, char **argv,
                       int *idx, int flag);
 
-/* Command -map */
+/* Commandis -map , -map_single */
 /* @param flag bit0=do not report the added item
                bit1=do not reset pacifier, no final pacifier message
+               bit5= -map_single: do not insert directory tree
 */
+/* @since 0.1.6 */
 int Xorriso_option_map(struct XorrisO *xorriso, char *disk_path,
                        char *iso_path, int flag);
 
@@ -1637,39 +1737,53 @@ int Xorriso_option_map(struct XorrisO *xorriso, char *disk_path,
                              2= -update_l
                              3= -extract_l
 */
+/* @since 0.2.0 */
 int Xorriso_option_map_l(struct XorrisO *xorriso, int argc, char **argv,
                          int *idx, int flag);
 
 /* Command -mark */
+/* @since 0.1.0 */
 int Xorriso_option_mark(struct XorrisO *xorriso, char *mark, int flag);
 
 /* Command -md5 */
+/* @since 0.4.2 */
 int Xorriso_option_md5(struct XorrisO *xorriso, char *mode, int flag);
 
 /* Command -mkdir alias -mkdiri */
+/* @since 0.1.0 */
 int Xorriso_option_mkdiri(struct XorrisO *xorriso, int argc, char **argv,
                           int *idx, int flag);
 
+/* Command -modesty_on_drive */
+/* @since 1.4.2 */
+int Xorriso_option_modesty_on_drive(struct XorrisO *xorriso, char *mode,
+                                    int flag);
+
 /* Command -mount , -mount_cmd , -session_string */
 /* @param bit0= -mount_cmd: print mount command to result channel rather
                             than performing it
           bit1= perform -session_string rather than -mount_cmd
 */ 
+/* @since 0.3.2 */
 int Xorriso_option_mount(struct XorrisO *xorriso, char *dev, char *adr_mode,
                          char *adr, char *cmd, int flag);
 
 /* Command -mount_opts option[:...] */
+/* @since 0.4.4 */
 int Xorriso_option_mount_opts(struct XorrisO *xorriso, char *mode, int flag);
 
 /* Command -move */
+/* @since 1.2.8 */
 int Xorriso_option_move(struct XorrisO *xorriso, char *origin, char *dest,
                         int flag);
 
 /* Command -msg_op */
+/* @since 1.2.6 */
 int Xorriso_option_msg_op(struct XorrisO *xorriso, char *what, char *arg,
                           int flag);
 
 /* Command -mv alias -mvi */
+/* @since 0.1.0 */
 int Xorriso_option_mvi(struct XorrisO *xorriso, int argc, char **argv,
                       int *idx, int flag);
 
@@ -1680,6 +1794,7 @@ int Xorriso_option_named_pipe_loop(struct XorrisO *xorriso, char *mode,
                                    char *stderr_pipe, int flag);
 
 /* Command -no_rc */
+/* @since 0.1.0 */
 int Xorriso_option_no_rc(struct XorrisO *xorriso, int flag);
 
 /* Command -not_leaf , -as mkisofs -hide without '/' */
@@ -1690,13 +1805,18 @@ int Xorriso_option_no_rc(struct XorrisO *xorriso, int flag);
                 bit2= add to HFS+ hide list rather than disk exclusions
                       @since 1.2.4
 */
+/* @since 0.1.6 */
 int Xorriso_option_not_leaf(struct XorrisO *xorriso, char *pattern, int flag);
 
 /* Command -not_list , -quoted_not_list */
-/* @param flag bit0= -quoted_not_list */
+/* @param flag bit0= -quoted_not_list
+                     @since 0.3.0
+ */
+/* @since 0.1.6 */
 int Xorriso_option_not_list(struct XorrisO *xorriso, char *adr, int flag);
 
 /* Command -not_mgt */
+/* @since 0.1.6 */
 int Xorriso_option_not_mgt(struct XorrisO *xorriso, char *setting, int flag);
 
 /* Command -not_paths , -as mkisofs -hide with '/' */
@@ -1711,44 +1831,56 @@ int Xorriso_option_not_mgt(struct XorrisO *xorriso, char *setting, int flag);
                    bit9= add to joliet_hidings, same as bit1
                   bit10= add to hfsplus_hidings
 */ 
+/* @since 0.1.6 */
 int Xorriso_option_not_paths(struct XorrisO *xorriso, int argc, char **argv,
                              int *idx, int flag);
 
 /* Command -options_from_file */
 /* @return <=0 error , 1 = success , 3 = request to end program run */
+/* @since 0.1.0 */
 int Xorriso_option_options_from_file(struct XorrisO *xorriso, char *adr,
                                      int flag);
 
 /* Command -osirrox "on"|"off" */
+/* @since 0.1.8 */
 int Xorriso_option_osirrox(struct XorrisO *xorriso, char *mode, int flag);
 
 /* Command -overwrite "on"|"nondir"|"off" */
+/* @since 0.1.0 */
 int Xorriso_option_overwrite(struct XorrisO *xorriso, char *mode, int flag);
 
 /* Command -pacifier */
+/* @since 0.2.2 */
 int Xorriso_option_pacifier(struct XorrisO *xorriso, char *style, int flag);
 
 /* Command -padding */
+/* @since 0.1.0 */
 int Xorriso_option_padding(struct XorrisO *xorriso, char *size, int flag);
 
 /* Command -page */
+/* @since 0.1.0 */
 int Xorriso_option_page(struct XorrisO *xorriso, int len, int width, int flag);
 
 /* Command -paste_in */
+/* @since 0.2.0 */
 int Xorriso_option_paste_in(struct XorrisO *xorriso, char *iso_rr_path,
                           char *disk_path, char *start, char *count, int flag);
 
 /* Command -path_list , -quoted_path_list */
-/* @param flag bit0= -quoted_path_list */
+/* @param flag bit0= -quoted_path_list @since 0.3.0
+*/
+/* @since 0.1.0 */
 int Xorriso_option_path_list(struct XorrisO *xorriso, char *adr, int flag);
 
 /* Command -pathspecs */
+/* @since 0.1.0 */
 int Xorriso_option_pathspecs(struct XorrisO *xorriso, char *mode, int flag);
 
 /* Command -pkt_output */
 /* Note: If output is redirected by Xorriso_push_outlists() then mode "on"
          consolidates output in the result output list, not on stdout.
 */
+/* @since 0.1.0 */
 int Xorriso_option_pkt_output(struct XorrisO *xorriso, char *mode, int flag);
 
 /* Command -preparer_id */
@@ -1761,72 +1893,96 @@ int Xorriso_option_preparer_id(struct XorrisO *xorriso, char *name, int flag);
                        1= info channel @since 1.0.6
                        2= mark channel @since 1.0.6
 */
+/* @since 1.0.6 */
 int Xorriso_option_print(struct XorrisO *xorriso, char *text, int flag);
 
 /* Command -print_size
    @param flag bit0= report in mkisofs compatible form on real stdout
 */
+/* @since 0.1.0 */
 int Xorriso_option_print_size(struct XorrisO *xorriso, int flag);
 
 /* Command -prog */
+/* @since 0.1.0 */
 int Xorriso_option_prog(struct XorrisO *xorriso, char *name, int flag);
 
 /* Command -prompt */
+/* @since 0.1.0 */
 int Xorriso_option_prompt(struct XorrisO *xorriso, char *text, int flag);
 
 /* Command -prog_help */
+/* @since 0.1.0 */
 int Xorriso_option_prog_help(struct XorrisO *xorriso, char *name, int flag);
 
 /* Command -publisher */
+/* @since 0.1.2 */
 int Xorriso_option_publisher(struct XorrisO *xorriso, char *name, int flag);
 
 /* Command -pvd_info */
+/* @since 0.4.4 */
 int Xorriso_option_pvd_info(struct XorrisO *xorriso, int flag);
 
 /* Command -pwd alias -pwdi */
+/* @since 0.1.0 */
 int Xorriso_option_pwdi(struct XorrisO *xorriso, int flag);
 
 /* Command -pwdx */
+/* @since 0.1.0 */
 int Xorriso_option_pwdx(struct XorrisO *xorriso, int flag);
 
+/* Command -read_fs */
+/* @since 1.4.2 */
+int Xorriso_option_read_fs(struct XorrisO *xorriso, char *mode, int flag);
+
 /* Command -read_mkisofsrc */
 /* @since 0.6.0 */
 int Xorriso_option_read_mkisofsrc(struct XorrisO *xorriso, int flag);
 
 /* Command -reassure "on"|"tree"|"off" */
+/* @since 0.1.0 */
 int Xorriso_option_reassure(struct XorrisO *xorriso, char *mode, int flag);
 
 /* Command -report_about */
+/* @since 0.1.0 */
 int Xorriso_option_report_about(struct XorrisO *xorriso, char *severity, 
                                 int flag);
 
 /* Command -report_el_torito */
+/* @since 1.3.8 */
 int Xorriso_option_report_el_torito(struct XorrisO *xorriso,
                                     char *form, int flag);
 
 /* Command -report_system_area */
+/* @since 1.3.8 */
 int Xorriso_option_report_system_area(struct XorrisO *xorriso,
                                       char *form, int flag);
 
 /* Command -return_with */
+/* @since 0.1.0 */
 int Xorriso_option_return_with(struct XorrisO *xorriso, char *severity,
                                int exit_value, int flag);
 
 /* Command -rm alias -rmi , -rm_r alias -rm_ri , -rmdir alias -rmdiri */
-/* @param flag bit0=recursive , bit2= remove empty directory: rmdir */
+/* @param flag bit0=recursive
+               bit2= remove empty directory: rmdiri
+ */
+/* @since 0.1.0 */
 int Xorriso_option_rmi(struct XorrisO *xorriso, int argc, char **argv,
                        int *idx, int flag);
 
 /* Command -rockridge "on"|"off" */
+/* @since 1.2.4 */
 int Xorriso_option_rockridge(struct XorrisO *xorriso, char *mode, int flag);
 
 /* Command -rollback */
 /* @param flag bit0= do not -reassure
    @return <=0 error , 1 success, 2 revoked by -reassure
 */
+/* @since 0.1.0 */
 int Xorriso_option_rollback(struct XorrisO *xorriso, int flag);
 
 /* Command -rom_toc_scan */
+/* @since 0.1.6 */
 int Xorriso_option_rom_toc_scan(struct XorrisO *xorriso, char *mode, int flag);
 
 /* Command -rr_reloc_dir */
@@ -1834,37 +1990,45 @@ int Xorriso_option_rom_toc_scan(struct XorrisO *xorriso, char *mode, int flag);
 int Xorriso_option_rr_reloc_dir(struct XorrisO *xorriso, char *name, int flag);
 
 /* Command -scdbackup_tag */
+/* @since 0.4.4 */
 int Xorriso_option_scdbackup_tag(struct XorrisO *xorriso, char *list_path,
                                  char *record_name, int flag);
 /* Command -scsi_log */
+/* @since 0.5.0 */
 int Xorriso_option_scsi_log(struct XorrisO *xorriso, char *mode, int flag);
 
 /* Command -session_log */
+/* @since 0.1.4 */
 int Xorriso_option_session_log(struct XorrisO *xorriso, char *path, int flag);
 
 /* Command -setfacl_list alias -setfacl_listi */
+/* @since 0.3.4 */
 int Xorriso_option_setfacl_listi(struct XorrisO *xorriso, char *disk_path,
                                  int flag);
 
 /* Command -setfacl alias -setfacli , -setfacl_r  alias -setfacl_ri */
-/* @param flag bit0=recursive -setfacl_r
-*/
+/* @param flag bit0=recursive -setfacl_r */
+/* @since 0.3.4 */
 int Xorriso_option_setfacli(struct XorrisO *xorriso, char *acl_text,
                             int argc, char **argv, int *idx, int flag);
 
 /* Command -setfattr alias -setfattri, -setfattr_r alias -setfattr_ri */
-/* @param flag   bit0=recursive -setfattr_r
-*/
+/* @param flag   bit0=recursive -setfattr_r */
+/* @since 0.3.4 */
 int Xorriso_option_setfattri(struct XorrisO *xorriso, char *name, char *value,
                             int argc, char **argv, int *idx, int flag);
 
 /* Command -setfattr_list alias -setfattr_listi */
+/* @since 0.3.4 */
 int Xorriso_option_setfattr_listi(struct XorrisO *xorriso, char *path, 
                                   int flag);
 
-/* Command -set_filter , -set_filter_r */ 
+/* Command -set_filter , -set_filter_r , -show_stream , -show_stream_r  */ 
 /* @param flag   bit0=recursive -set_filter_r
-*/
+                 bit1= do not reset pacifier, no final pacifier message
+                 bit2= -show_stream rather than -set_filter
+ */
+/* @since 0.3.8 */
 int Xorriso_option_set_filter(struct XorrisO *xorriso, char *name,
                               int argc, char **argv, int *idx, int flag);
 
@@ -1886,49 +2050,61 @@ int Xorriso_option_sleep(struct XorrisO *xorriso, char *duration, int flag);
 
 /* Command -speed , -read_speed */
 /* @param flag bit0= @since 1.3.4
-                     -read_speed rather than -speed
-*/ 
+                     -read_speed rather than -speed */ 
+/* @since 0.1.0 */
 int Xorriso_option_speed(struct XorrisO *xorriso, char *speed, int flag);
 
 /* Command -split_size */
+/* @since 0.1.4 */
 int Xorriso_option_split_size(struct XorrisO *xorriso, char *s, int flag);
 
 /* Command -status */
+/* @since 0.1.0 */
 int Xorriso_option_status(struct XorrisO *xorriso, char *mode, int flag);
 
 /* Command -status_history_max */
+/* @since 0.1.0 */
 int Xorriso_option_status_history_max(struct XorrisO *xorriso, int num1, 
                                       int flag);
 
 /* Command -stdio_sync "on"|"off"|"end"|size */
+/* @since 0.4.6 */
 int Xorriso_option_stdio_sync(struct XorrisO *xorriso, char *rythm, int flag);
 
 /* Command -stream_recording */
+/* @since 0.1.8 */
 int Xorriso_option_stream_recording(struct XorrisO *xorriso, char *mode,
                                     int flag);
 
 /* Command -system_id */
+/* @since 0.4.4 */
 int Xorriso_option_system_id(struct XorrisO *xorriso, char *name, int flag);
 
 /* Command -tell_media_space */
+/* @since 0.1.0 */
 int Xorriso_option_tell_media_space(struct XorrisO *xorriso, int flag);
 
 /* Command -temp_mem_limit */
+/* @since 0.1.0 */
 int Xorriso_option_temp_mem_limit(struct XorrisO *xorriso, char *size, 
                                   int flag);
 
 /* Command -toc */
 /* @param flag   bit0= short report form as with -dev, no table-of-content
 */
+/* @since 0.1.0 */
 int Xorriso_option_toc(struct XorrisO *xorriso, int flag);
 
 /* Command -toc_of */
+/* @since 1.2.6 */
 int Xorriso_option_toc_of(struct XorrisO *xorriso, char *which, int flag);
 
 /* Command -uid */
+/* @since 0.1.0 */
 int Xorriso_option_uid(struct XorrisO *xorriso, char *uid, int flag);
 
 /* Command -unregister_filter */
+/* @since 0.3.8 */
 int Xorriso_option_unregister_filter(struct XorrisO *xorriso, char *name,
                                      int flag);
 
@@ -1938,13 +2114,16 @@ int Xorriso_option_unregister_filter(struct XorrisO *xorriso, char *name,
                bit2= do not issue pacifier messages at all
                bit3= recursive: -update_r
 */ 
+/* @since 0.1.2 */
 int Xorriso_option_update(struct XorrisO *xorriso, char *disk_path,
                           char *iso_path, int flag);
 
 /* Command -use_readline */
+/* @since 0.1.0 */
 int Xorriso_option_use_readline(struct XorrisO *xorriso, char *mode, int flag);
 
 /* Command -version */
+/* @since 0.1.0 */
 int Xorriso_option_version(struct XorrisO *xorriso, int flag);
 
 /* Command -volid */
@@ -1953,24 +2132,30 @@ int Xorriso_option_version(struct XorrisO *xorriso, int flag);
 int Xorriso_option_volid(struct XorrisO *xorriso, char *volid, int flag);
 
 /* Command -volset_id */
+/* @since 0.4.4 */
 int Xorriso_option_volset_id(struct XorrisO *xorriso, char *name, int flag);
 
 /* Command -volume_date */
+/* @since 0.5.4 */
 int Xorriso_option_volume_date(struct XorrisO *xorriso,
                                char *time_type, char *timestring, int flag);
 
 /* Command -write_type */
+/* @since 1.2.4 */
 int Xorriso_option_write_type(struct XorrisO *xorriso, char *mode, int flag);
 
 /* There is no Xorriso_option_x() because -x has an effect only in
    Xorriso_prescan_args(). Use the flag bits of Xorriso_interpreter() if
    you want to impose command sorting on your own.
+   @since 1.2.2
 */
 
 /* Command -xattr "on"|"off" */
+/* @since 0.3.4 */
 int Xorriso_option_xattr(struct XorrisO *xorriso, char *mode, int flag);
 
 /* Command -zisofs */
+/* @since 0.3.8 */
 int Xorriso_option_zisofs(struct XorrisO *xorriso, char *mode, int flag);
 
 
