@@ -146,6 +146,7 @@ struct XorrisO { /* the global context of xorriso */
  int do_fat;
  int do_rockridge;
  int do_iso1999;
+ int ecma119_map;     /* 0=unmapped , 1=stripped , 2=uppercase , 3=lowercase */
 
  int do_aaip; /* bit0= ACL in
                  bit1= ACL out
@@ -156,7 +157,7 @@ struct XorrisO { /* the global context of xorriso */
                  bit6= omit content check if bit5 check is conclusive
                  bit7= omit dev check with bit5
                  bit8= store output charset in xattr "isofs.cs"
-                 bit9= allow to set input charset from xattr "isofs.cs"
+                 bit9= set input charset from xattr "isofs.cs"
               */
 
  int do_md5;  /* bit0= read MD5 array
@@ -277,6 +278,8 @@ struct XorrisO { /* the global context of xorriso */
  uint32_t displacement;
  int displacement_sign;
 
+ int read_fs;            /* bit0=norock , bit1=nojoliet */
+
  int drives_exclusive;   /* burn_preset_device_open() param exclusive */
 
  int early_stdio_test;   /* For burn_allow_drive_role_4():
@@ -303,7 +306,7 @@ struct XorrisO { /* the global context of xorriso */
  char *in_charset;       /* The charset to interpret the filename bytes */
  int indev_is_exclusive;
  char indev_off_adr[SfileadrL]; /* Result of burn_drive_convert_fs_adr(indev)
-                                   when indev gets aquired. */
+                                   when indev gets acquired. */
 
  time_t isofs_st_out;    /* A time point at least 1 second before image
                             composition began. To be stored with image as
@@ -334,7 +337,7 @@ struct XorrisO { /* the global context of xorriso */
                   */
  int outdev_is_exclusive;
  char outdev_off_adr[SfileadrL]; /* Result of burn_drive_convert_fs_adr(outdev)
-		        	    when outdev gets aquired. */
+		        	    when outdev gets acquired. */
 
  int grow_blindly_msc2; /* if >= 0 this causes growing from drive to drive.
                            The value is used as block address offset for
@@ -365,6 +368,16 @@ struct XorrisO { /* the global context of xorriso */
 
  int dvd_obs;                 /* DVD write chunk size: 0, 32k or 64k */
 
+ int modesty_on_drive;        /* "enable" of burn_drive_set_buffer_waiting()
+                                 0= disable , 1= enable waiting ,
+                                 (-1 = do not change setting)
+                               */
+ int min_buffer_usec;         /* The other parameters for this function */
+ int max_buffer_usec;
+ int buffer_timeout_sec;
+ int min_buffer_percent;
+ int max_buffer_percent;
+
  int stdio_sync;              /* stdio fsync interval: -1, 0, >=32 */
  int stdio_sync_is_default;   /* 1= is still default , 0= has been set */
 
@@ -593,6 +606,7 @@ struct XorrisO { /* the global context of xorriso */
  int temp_mem_limit;
 
  off_t file_size_limit;
+ int file_name_limit;
 
  struct ExclusionS *disk_exclusions;
  int disk_excl_mode; /* bit0= on (else off)
@@ -722,6 +736,10 @@ struct XorrisO { /* the global context of xorriso */
                                bit2= seen data file without MD5
                                bit3= seen match
                              */
+ int find_unique_trunc_result; /* 0= some names are not uniquely truncatable
+                                  1= all names are uniquely truncatable
+                                  2= no names need truncation
+                                */
 
  double last_abort_file_time; /* most recent check for aborting -check_md5 */
 
